from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsGreatAdventure(SixFlagsPark):
    def __init__(self):
        super(SixFlagsGreatAdventure, self).__init__()

    def getId(self):
        return 5
    def getCity(self):
        return 'Jackson'
    def getName(self):
        return 'Six Flags Great Adventure'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborOklahomaCity(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborOklahomaCity, self).__init__()

    def getId(self):
        return 44
    def getCity(self):
        return 'Oklahoma City'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Oklahoma City'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsWhiteWaterAtlanta(SixFlagsPark):
    def __init__(self):
        super(SixFlagsWhiteWaterAtlanta, self).__init__()

    def getId(self):
        return 25
    def getCity(self):
        return 'Marietta'
    def getName(self):
        return 'Six Flags White Water, Atlanta'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class TheGreatEscape(SixFlagsPark):
    def __init__(self):
        super(TheGreatEscape, self).__init__()

    def getId(self):
        return 24
    def getCity(self):
        return 'Queensbury'
    def getName(self):
        return 'The Great Escape'

    


#!/usr/bin/env python
import requests
from pymusement.park import Park
from pymusement.ride import Ride
from pymusement.show import Show
import datetime

PARK_URL = 'https://public.api.seaworld.com/v1/park/{0}/'
RIDE_URL = 'https://public.api.seaworld.com/v1/park/{0}/availability'
#SHOW_URL = 'https://seas.te2.biz/v1/rest/venue/{0}/shows/{1}'

class SeaworldPark(Park):
        
    def __init__(self):
        super(SeaworldPark, self).__init__()
        self._park_url = PARK_URL.format(self.getId())
        self._ride_url = RIDE_URL.format(self.getId())

    def _buildPark(self):
        parsed_page = requests.get(self._park_url).json()
        wait_times = requests.get(self._ride_url).json()
        times = wait_times['WaitTimes']
        wait_times = { x['Id']:x['Minutes'] for x in times }
        ride_status = { x['Id']:x['Status'] for x in times }
        hour_page = parsed_page['open_hours']
        for date in hour_page:
                open_time, close_time = datetime.datetime.fromisoformat(date['opens_at'][:-1]), datetime.datetime.fromisoformat(date['closes_at'][:-1])

                if open_time < datetime.datetime.now() < close_time:
                    self.set_open()
                    self.park_hours = open_time.time().strftime('%r') + ' ' + close_time.time().strftime('%r')
                    break
                else:
                    self.set_closed()
                    self.park_hours = open_time.time().strftime('%r') + ' ' + close_time.time().strftime('%r')
                    break
        
        for ride in parsed_page['POIs']['Rides']:
            try:
                ride.update({'WaitTime':wait_times[ride['Id']]})
            except KeyError:
                ride.update({'WaitTime':-1})
            try:
                ride.update({'Status':ride_status[ride['Id']]})
            except KeyError:
                ride.update({'Status':''})
            self._make_attraction(ride)
    def _make_attraction(self, ride):
        # Create dictionary with attraction information
        attraction = Ride()
        attraction.setName(ride['Name'])
        
       # if not self.is_Open:
       #     attraction.setTime(0)
       #     attraction.setClosed()
       #     self.addRide(attraction)
       #     return
        
        if ride['WaitTime'] is None:
            attraction.setClosed()
        else:
            attraction.setOpen() 
        
        if ride['WaitTime'] == -1:
            attraction.setClosed()
            attraction.setTime(-1)
            attraction.setStatus(ride['Status'])
        else:
            attraction.setTime(ride['WaitTime'])
            attraction.setStatus('Operating')
            
            
        self.addRide(attraction)
        

 



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsDarienLake(SixFlagsPark):
    def __init__(self):
        super(SixFlagsDarienLake, self).__init__()

    def getId(self):
        return 45
    def getCity(self):
        return 'Darien Center'
    def getName(self):
        return 'Six Flags Darien Lake'

    


#!/usr/bin/env python
from pymusement.parks.seaworld.SeaworldPark import SeaworldPark

class SeaworldSanDiego(SeaworldPark):
    def __init__(self):
        super(SeaworldSanDiego, self).__init__()

    def getId(self):
        return '4325312F-FDF1-41FF-ABF4-361A4FF03443'

    def getName(self):
        return 'Seaworld San Diego'
    def getCity(self):
        return 'san-diego'


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborPhoenix(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborPhoenix, self).__init__()

    def getId(self):
        return 46
    def getCity(self):
        return 'Glendale'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Phoenix'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsFiestaTexas(SixFlagsPark):
    def __init__(self):
        super(SixFlagsFiestaTexas, self).__init__()

    def getId(self):
        return 8
    def getCity(self):
        return 'San Antonio'
    def getName(self):
        return 'Six Flags Fiesta Texas'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborChicago(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborChicago, self).__init__()

    def getId(self):
        return 13
    def getCity(self):
        return 'Gurnee'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Chicago'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsOverGeorgia(SixFlagsPark):
    def __init__(self):
        super(SixFlagsOverGeorgia, self).__init__()

    def getId(self):
        return 2
    def getCity(self):
        return 'Austell'
    def getName(self):
        return 'Six Flags Over Georgia'






from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsDiscoveryKingdom(SixFlagsPark):
    def __init__(self):
        super(SixFlagsDiscoveryKingdom, self).__init__()

    def getId(self):
        return 17
    def getCity(self):
        return 'Vallejo'
    def getName(self):
        return 'Six Flags Discovery Kingdom'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsNewEngland(SixFlagsPark):
    def __init__(self):
        super(SixFlagsNewEngland, self).__init__()

    def getId(self):
        return 20
    def getCity(self):
        return 'Agawam'
    def getName(self):
        return 'Six Flags New England'

    


from pymusement.parks.universal.UniversalStudiosFlorida import UniversalStudiosFlorida
from pymusement.parks.universal.IslandsOfAdventure import IslandsOfAdventure
from pymusement.parks.universal.UniversalHollywood import UniversalHollywood
from pymusement.parks.universal.UniversalVolcano import UniversalVolcano
from pymusement.parks.universal.UniversalEpicUniverse import UniversalEpicUniverse
from pymusement.parks.HersheyPark import HersheyPark
from pymusement.parks.disney.AnimalKingdom import AnimalKingdom
from pymusement.parks.disney.CaliforniaAdventure import CaliforniaAdventure
from pymusement.parks.disney.Disneyland import Disneyland
from pymusement.parks.disney.Epcot import Epcot
from pymusement.parks.disney.HollywoodStudios import HollywoodStudios
from pymusement.parks.disney.MagicKingdom import MagicKingdom
from pymusement.parks.sixflags.SixFlagsOverTexas import SixFlagsOverTexas
from pymusement.parks.sixflags.SixFlagsOverGeorgia import SixFlagsOverGeorgia
from pymusement.parks.sixflags.SixFlagsStLouis import SixFlagsStLouis
from pymusement.parks.sixflags.SixFlagsGreatAdventure import SixFlagsGreatAdventure
from pymusement.parks.sixflags.SixFlagsMagicMountain import SixFlagsMagicMountain
from pymusement.parks.sixflags.SixFlagsGreatAmerica import SixFlagsGreatAmerica
from pymusement.parks.sixflags.SixFlagsFiestaTexas import SixFlagsFiestaTexas
from pymusement.parks.sixflags.SixFlagsHurricaneHarborArlington import SixFlagsHurricaneHarborArlington
from pymusement.parks.sixflags.SixFlagsHurricaneHarborLosAngeles import SixFlagsHurricaneHarborLosAngeles
from pymusement.parks.sixflags.SixFlagsHurricaneHarborChicago import SixFlagsHurricaneHarborChicago
from pymusement.parks.sixflags.SixFlagsAmerica import SixFlagsAmerica
from pymusement.parks.sixflags.SixFlagsDiscoveryKingdom import SixFlagsDiscoveryKingdom
from pymusement.parks.sixflags.SixFlagsNewEngland import SixFlagsNewEngland
from pymusement.parks.sixflags.SixFlagsHurricaneHarborJackson import SixFlagsHurricaneHarborJackson
from pymusement.parks.sixflags.TheGreatEscape import TheGreatEscape
from pymusement.parks.sixflags.SixFlagsWhiteWaterAtlanta import SixFlagsWhiteWaterAtlanta
from pymusement.parks.sixflags.SixFlagsMexico import SixFlagsMexico
from pymusement.parks.sixflags.LaRondeMontreal import LaRondeMontreal
from pymusement.parks.sixflags.SixFlagsHurricaneHarborOaxtepec import SixFlagsHurricaneHarborOaxtepec
from pymusement.parks.sixflags.SixFlagsHurricaneHarborConcord import SixFlagsHurricaneHarborConcord
from pymusement.parks.sixflags.SixFlagsFrontierCity import SixFlagsFrontierCity
from pymusement.parks.sixflags.SixFlagsHurricaneHarborOklahomaCity import SixFlagsHurricaneHarborOklahomaCity
from pymusement.parks.sixflags.SixFlagsDarienLake import SixFlagsDarienLake
from pymusement.parks.sixflags.SixFlagsHurricaneHarborPhoenix import SixFlagsHurricaneHarborPhoenix
from pymusement.parks.sixflags.SixFlagsHurricaneHarborSplashTown import SixFlagsHurricaneHarborSplashTown
from pymusement.parks.sixflags.SixFlagsHurricaneHarborRockford import SixFlagsHurricaneHarborRockford
from pymusement.parks.seaworld.SeaworldOrlando import SeaworldOrlando
from pymusement.parks.seaworld.BuschGardensTampa import BuschGardensTampa
from pymusement.parks.seaworld.SeaworldSanAntonio import SeaworldSanAntonio
from pymusement.parks.seaworld.SeaworldSanDiego import SeaworldSanDiego
from pymusement.parks.seaworld.BuschGardensWilliamsburg import BuschGardensWilliamsburg



PARKS = {
    'universal-florida' : UniversalStudiosFlorida(),
    'islands-adventure' : IslandsOfAdventure(),
    'universal-hollywood' : UniversalHollywood(),
    'volcano-bay' : UniversalVolcano(),
    'epic-universe' : UniversalEpicUniverse(),
    'hersheypark' : HersheyPark(),
    'magic-kingdom' : MagicKingdom(),
    'animal-kingdom' : AnimalKingdom(),
    'epcot' : Epcot(),
    'hollywood-studios':HollywoodStudios(),
    'disneyland': Disneyland(),
    'california-adventure' : CaliforniaAdventure(),
    'six-flags-over-texas' : SixFlagsOverTexas(),
	'six-flags-over-georgia' : SixFlagsOverGeorgia(),
	'six-flags-st-louis' : SixFlagsStLouis(),
	'six-flags-great-adventure' : SixFlagsGreatAdventure(),
	'six-flags-magic-mountain' : SixFlagsMagicMountain(),
	'six-flags-great-america' : SixFlagsGreatAmerica(),
	'six-flags-fiesta-texas' : SixFlagsFiestaTexas(),
	'six-flags-hurricane-harbor-arlington' : SixFlagsHurricaneHarborArlington(),
	'six-flags-hurricane-harbor-los-angeles' : SixFlagsHurricaneHarborLosAngeles(),
	'six-flags-hurricane-harbor-chicago' : SixFlagsHurricaneHarborChicago(),
	'six-flags-america' : SixFlagsAmerica(),
	'six-flags-discovery-kingdom' : SixFlagsDiscoveryKingdom(),
	'six-flags-new-england' : SixFlagsNewEngland(),
	'six-flags-hurricane-harbor-jackson' : SixFlagsHurricaneHarborJackson(),
	'the-great-escape' : TheGreatEscape(),
	'six-flags-white-water-atlanta' : SixFlagsWhiteWaterAtlanta(),
	'six-flags-mexico' : SixFlagsMexico(),
	'la-ronde-montreal' : LaRondeMontreal(),
	'six-flags-hurricane-harbor-oaxtepec' : SixFlagsHurricaneHarborOaxtepec(),
	'six-flags-hurricane-harbor-concord' : SixFlagsHurricaneHarborConcord(),
	'six-flags-frontier-city' : SixFlagsFrontierCity(),
	'six-flags-hurricane-harbor-oklahoma-city' : SixFlagsHurricaneHarborOklahomaCity(),
	'six-flags-darien-lake' : SixFlagsDarienLake(),
	'six-flags-hurricane-harbor-phoenix' : SixFlagsHurricaneHarborPhoenix(),
	'six-flags-hurricane-harbor-splashtown' : SixFlagsHurricaneHarborSplashTown(),
	'six-flags-hurricane-harbor-rockford' : SixFlagsHurricaneHarborRockford(),
	'seaworld-orlando' : SeaworldOrlando(),
    'busch-gardens-tampa' : BuschGardensTampa(),
    'seaworld-san-antonio' : SeaworldSanAntonio(),
    'seaworld-san-diego' : SeaworldSanDiego(),
    'busch-gardens-williamsburg' : BuschGardensWilliamsburg()
}



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborLosAngeles(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborLosAngeles, self).__init__()

    def getId(self):
        return 11
    def getCity(self):
        return 'Valencia'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Los Angeles'

    


import unittest
from nose.tools import *

from pymusement.show import Show

class ShowTestCase(unittest.TestCase):
    
    def test_showtimeKey(self):
        show_obj = Show()
        self.assertEqual('showtimes' in show_obj.attributes(), True)

    def test_addTime(self):
        show_obj = Show()
        show_obj.addTime('12:00 PM')
        self.assertEqual(len(show_obj.getTimes()), 2)




from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class LaRondeMontreal(SixFlagsPark):
    def __init__(self):
        super(LaRondeMontreal, self).__init__()

    def getId(self):
        return 29
    def getCity(self):
        return 'Montreal'
    def getName(self):
        return 'La Ronde, Montreal'

    


import unittest
from nose.tools import *
from pymusement.ride import Ride

class RideTestCase(unittest.TestCase):

    def test_setOpen(self):
        ride = Ride()
        ride.setOpen()
        self.assertEqual(ride['isOpen'], True)

    def test_setClosed(self):
        ride = Ride()
        ride.setClosed()
        self.assertEqual(ride['isOpen'], False)

    def test_isOpen(self):
        ride = Ride()
        ride.setClosed()
        self.assertEqual(ride.isOpen(), False)

    def test_setTimeString(self):
        ride = Ride()
        test_time_str = '10'
        test_time_int = int(test_time_str)
        ride.setTime(test_time_str)
        self.assertEquals(ride['wait'], test_time_int)

    def test_setTimeInt(self):
        ride = Ride()
        test_time_str = '10'
        test_time_int = int(test_time_str)
        ride.setTime(test_time_int)
        self.assertEquals(ride['wait'], test_time_int)



import requests
import datetime
from pymusement.park import Park
from pymusement.ride import Ride

SHARED_HEADERS = {
    'Accept'                          : 'application/json',
    'Accept-Language'                 : 'en-US',
    'X-UNIWebService-AppVersion'      : '1.2.1',
    'X-UNIWebService-Platform'        : 'Android',
    'X-UNIWebService-PlatformVersion' : '4.4.2',
    'X-UNIWebService-Device'          : 'samsung SM-N9005',
    'X-UNIWebService-ServiceVersion'  : '1',
    'User-Agent'                      : 'Dalvik/1.6.0 (Linux; U; Android 4.4.2; SM-N9005 Build/KOT49H)',
    'Connection'                      : 'keep-alive',
    'Accept-Encoding'                 : 'gzip'
  }

WAIT_URL = 'https://api.sixflags.net/mobileapi/v1/park/{0}/rideStatus'

META_URL = 'https://api.sixflags.net/mobileapi/v1/park/{0}/ride'

HOURS_URL = 'https://api.sixflags.net/mobileapi/v1/park/{0}/hours'


class SixFlagsPark(Park):
    def __init__(self):
        super(SixFlagsPark, self).__init__()
        self.ride_url = WAIT_URL.format(self.getId())
        self.info_url = META_URL.format(self.getId())
        self.hour_url = HOURS_URL.format(self.getId())
    def getId(self):
        raise('This must be implemented in a sub class')
        
    def _buildPark(self):
        token = self._get_token()
        ride_page = self._get_request(token, self.ride_url)
        metadata_page = self._get_request(token, self.info_url)
        hour_page = self._get_request(token,self.hour_url)
            
        ride_info = {x['rideId']:x for x in metadata_page['rides']}
        
        try:
            hours = -1
            for time in hour_page['operatingHours']:
                if datetime.datetime.fromisoformat(time['operatingDate']).date() == datetime.date.today():

                    hours = time
                    break
            if hours == -1:
                self.set_closed()
                self.park_hours = 'Closed'
            else:
                open_time, close_time = datetime.datetime.fromisoformat(hours['open']), datetime.datetime.fromisoformat(hours['close'])
                self.park_hours = open_time.time().strftime('%r') + ' ' + close_time.time().strftime('%r')
               
                if open_time < datetime.datetime.now() < close_time:
                    self.set_open()
                    self.park_hours = open_time.time().strftime('%r') + ' ' + close_time.time().strftime('%r')
                
                else:
                    self.set_closed()
                    self.park_hours = open_time.time().strftime('%r') + ' ' + close_time.time().strftime('%r')
                
        except IndexError:
            self.set_closed()
            self.park_hours = 'Closed'
            
            
               
        
        for ride in ride_page['rideStatuses']:
            self._make_attraction(ride,ride_info[ride['rideId']])

    def _make_attraction(self, ride, meta):
        attraction = Ride()
        attraction.setName(meta['name'])
        attraction.setStatus(meta['status'])
        
        #Check if Park is Open
        if not self.is_Open:
            attraction.setTime(0)
            attraction.setClosed()
            attraction.set_skip_line(meta['isFlashPassEligible'])
            self.addRide(attraction)
            return

        if meta['status'] == 'AttractionStatusOpen':
            attraction.setOpen()
        else:
            attraction.setClosed()
        try:
            int(ride['waitTime'])
        except ValueError:
            ride['waitTime'] = ''.join(c for c in ride['waitTime'] if c.isdigit())
        except TypeError:
            if ride['waitTime']: raise ValueError
            else: ride['waitTime'] = 0
        attraction.setTime(ride['waitTime'])
        attraction.set_skip_line(meta['isFlashPassEligible'])

        
        
        
        self.addRide(attraction)


    def _get_request(self, token, url):
        headers={'Authorization': 'Bearer '+ token}
        r = requests.get(url, headers=headers)
        return r.json()

    def _get_token(self):
        headers = {
            'Authorization':'Basic MEExQ0RGNjctMjQ3Ni00Q0IyLUFCM0ItMTk1MTNGMUY3NzQ3Ok10WEVKU0hMUjF5ekNTS3FBSVZvWmt6d2ZDUUFUNEIzTVhIZ20rZVRHU29xSkNBRDRXUHlIUnlYK0drcFZYSHJBNU9ZdUFKRHYxU3p3a3UxWS9sM0Z3PT0='
        }
        data={"grant_type":"client_credentials","scope":"mobileApp"}
        r = requests.post('https://api.sixflags.net/Authentication/identity/connect/token', headers=headers,data=data)
        return r.json()['access_token']



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsMagicMountain(SixFlagsPark):
    def __init__(self):
        super(SixFlagsMagicMountain, self).__init__()

    def getId(self):
        return 6
    def getCity(self):
        return 'Valencia'
    def getName(self):
        return 'Six Flags Magic Mountain'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsOrlando(SixFlagsPark):
    def __init__(self):
        super(SixFlagsOrlando, self).__init__()

    def getId(self):
        return 1234
    def getCity(self):
        return 'Orlando'
    def getName(self):
        return 'Six Flags Orlando'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborRockford(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborRockford, self).__init__()

    def getId(self):
        return 48
    def getCity(self):
        return 'Cherry Valley'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Rockford'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborConcord(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborConcord, self).__init__()

    def getId(self):
        return 42
    def getCity(self):
        return 'Concord'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Concord'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsAmerica(SixFlagsPark):
    def __init__(self):
        super(SixFlagsAmerica, self).__init__()

    def getId(self):
        return 14
    def getCity(self):
        return 'Bowie'
    def getName(self):
        return 'Six Flags America'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborArlington(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborArlington, self).__init__()

    def getId(self):
        return 10
    def getCity(self):
        return 'Arlington'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Arlington'

    


import unittest
from nose.tools import *
from pymusement.attraction import Attraction

class AttractionTest(unittest.TestCase):

    @raises(Exception)
    def test_invalidget(self):
        attr = Attraction()
        attr['invalid_name']

    @raises(Exception)
    def test_invalidset(self):
        attr = Attraction()
        attr['invalid_name'] = 'invalid_set'

    def test_setName(self):
        attr = Attraction()
        name = 'test_name'
        attr.setName(name)
        self.assertEquals(attr.getName(), name)

    def test_addKeys(self):
        key_name = 'newkey1'
        keys = [key_name]
        attr = Attraction()
        attr._addKeys(keys)
        attr[key_name]
        self.assertEquals(len(attr.attributes()), 2)
        



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsStLouis(SixFlagsPark):
    def __init__(self):
        super(SixFlagsStLouis, self).__init__()

    def getId(self):
        return 3
    def getCity(self):
        return 'Eureka'
    def getName(self):
        return 'Six Flags St. Louis'

    


import unittest
from nose.tools import *

from pymusement.park import Park
from pymusement.show import Show
from pymusement.ride import Ride

class ParkTestCase(unittest.TestCase):
    @raises(Exception)
    def test_rides_no_rides(self):
        park = Park()
        self.assertEqual(park.rides(), [])

    @raises(Exception)
    def test_shows_no_shows(self):
        park = Park()
        self.assertEqual(park.shows(), [])

    def test_addRide(self):
        park = Park()
        ride = Ride()
        park.addRide(ride)
        self.assertEqual(len(park.rides()), 1)

    def test_addShow(self):
        park = Park()
        show = Show()
        park.addShow(show)
        self.assertEqual(len(park.shows()), 1)



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsMexico(SixFlagsPark):
    def __init__(self):
        super(SixFlagsMexico, self).__init__()

    def getId(self):
        return 28
    def getCity(self):
        return 'Ciudad de México'
    def getName(self):
        return 'Six Flags México'

    



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsFrontierCity(SixFlagsPark):
    def __init__(self):
        super(SixFlagsFrontierCity, self).__init__()

    def getId(self):
        return 43
    def getCity(self):
        return 'Oklahoma City'
    def getName(self):
        return 'Six Flags Frontier City'

    


from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborOaxtepec(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborOaxtepec, self).__init__()

    def getId(self):
        return 32
    def getCity(self):
        return 'Oaxtepec'
    def getName(self):
        return 'Six Flags Hurricane Harbor, Oaxtepec'

    


#!/usr/bin/env python
import requests
import json
import datetime
from pymusement.park import Park
from pymusement.ride import Ride

URL_TEMPLATE = 'https://api.themeparks.wiki/preview/parks/%s'
class DisneyPark(Park):

    def __init__(self):
        self._id = self.getId()
        self._url = URL_TEMPLATE % self.get_api_id()
        self.name = self.getName()
        super(DisneyPark, self).__init__()

    def getId(self):
        raise('This must be implemented in a subclass')

    def get_api_id(self):
        raise('This must be implemented in a subclass')
    
    def getName(self):
        raise('This must be implemented in a subclass')

    def _buildPark(self):
        page = self._get_page()
        for attraction in page:
            if 'type' in attraction['meta'] and attraction['meta']['type'] != 'ATTRACTION':
                continue
            self._build_attraction(attraction)

    def _build_attraction(self, attraction):
        attraction_obj = Ride()

        attraction_obj.setName(attraction['name'])
         
        if attraction['active']:
            attraction_obj.setOpen()
            attraction_obj.setTime(attraction['waitTime'])
        else:
            attraction_obj.setTime(0)
            attraction_obj.setClosed()
        attraction_obj.set_skip_line(attraction['fastPass'])
        attraction_obj.setSingleRider(attraction['meta']['singleRider'])
    
        self.addRide(attraction_obj)
    
    def _get_page(self):
        ride_link = self._url + '/waittime'
        page = requests.get(ride_link).json()
        return page


        



from pymusement.parks.sixflags.SixFlagsPark import SixFlagsPark
    
class SixFlagsHurricaneHarborSplashTown(SixFlagsPark):
    def __init__(self):
        super(SixFlagsHurricaneHarborSplashTown, self).__init__()

    def getId(self):
        return 47
    def getCity(self):
        return 'Spring'
    def getName(self):
        return 'Six Flags Hurricane Harbor, SplashTown'

    